@@ -14,16 +14,23 @@
 from __future__ import absolute_import, division, print_function
 
 __all__ = [
-    "__title__", "__summary__", "__uri__", "__version__", "__author__",
-    "__email__", "__license__", "__copyright__",
+    "__title__",
+    "__summary__",
+    "__uri__",
+    "__version__",
+    "__author__",
+    "__email__",
+    "__license__",
+    "__copyright__",
 ]
 
 __title__ = "readme_renderer"
-__summary__ = ('readme_renderer is a library for rendering "readme" '
-               'descriptions for Warehouse')
+__summary__ = (
+    'readme_renderer is a library for rendering "readme" ' "descriptions for Warehouse"
+)
 __uri__ = "https://github.com/pypa/readme_renderer"
 
-__version__ = "20.0"
+__version__ = "34.0"
 
 __author__ = "The Python Packaging Authority"
 __email__ = "admin@mail.pypi.org"
